@@ -931,7 +931,7 @@ class DataCorresponder:
         
         return X_data, y_data, id_data
 
-class DataLazyCorresponder:
+class LazyDataCorresponder:
     def __init__(self, all_vec_data_path):
         self.all_vec_data_path = all_vec_data_path
     
